const webpack = require('webpack');
const path = require('path');
const buildPath = path.resolve(__dirname, 'build');
const nodeModulesPath = path.resolve(__dirname, 'node_modules');
const TransferWebpackPlugin = require('transfer-webpack-plugin');

const config = {
  //Entry points to the project
  entry: [
    'webpack/hot/dev-server',
    'webpack/hot/only-dev-server',
    path.join(__dirname, '/www/app.js')
  ],
  //Config options on how to interpret requires imports
  resolve: {
    extensions: ["", ".js"]
    //node_modules: ["web_modules", "node_modules"]  (Default Settings)
  },
  //Server Configuration options
  devServer:{
    contentBase: 'www/app',  //Relative directory for base of server
    devtool: 'eval',
    hot: true,        //Live-reload
    inline: true,
    port: 3000,        //Port Number
    host: 'localhost'  //Change to '0.0.0.0' for external facing server
  },
  devtool: 'eval',
  output: {
    path: buildPath,    //Path of output file
    filename: 'app.js'
  },
  plugins: [
    //Enables Hot Modules Replacement
    new webpack.HotModuleReplacementPlugin(),
    //Allows error warnings but does not stop compiling. Will remove when eslint is added
    new webpack.NoErrorsPlugin(),
    //Moves files
    new TransferWebpackPlugin([
      {from: 'app'},
    ], path.resolve(__dirname, "www"))
  ],
  module: {
    //Loaders to interpret non-vanilla javascript code as well as most other extensions including images and text.
    // preLoaders: [
    //   {
    //     //Eslint loader
    //     test: /\.js$/,
    //     loader: 'eslint-loader',
    //     include: [path.resolve(__dirname, 'components')],
    //     exclude: [nodeModulesPath],
    //   },
    // ],
    loaders: [
      {
        //React-hot loader and
        test: /\.js$/,  //All .js files
        loaders: ['react-hot', 'babel'], //react-hot is like browser sync and babel loads jsx and es6-7
        exclude: [nodeModulesPath],
      },
      {
        test: /\.(css|scss|sass)$/,
        loader: "style-loader!css-loader!sass-loader",
      },
      {
        test: /\.css$/,
        exclude: /node_modules/,
        loader: 'null'
      },
      {
        test: /\.(png|jpg|gif|woff)$/,
        loader: 'url-loader?limit=8192'
      }, 
      {
        test: /\.(ttf|eot|svg)(\?v=[0-9]\.[0-9]\.[0-9])?$/,
        loader: "file-loader"
      }
    ],
    resolve: {
      root: path.join(__dirname, 'node_modules'),
    }
  }
  //eslint config options. Part of the eslint-loader package
  // eslint: {
  //   configFile: '.eslintrc',
  // },
};

module.exports = config;
